[SCM] exiv2 packaging branch, master, updated. debian/0.25-3.1-3734-gdcbc29a

Maximiliano Curia maxy at moszumanska.debian.org
Thu Jul 13 17:36:14 UTC 2017


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/exiv2.git;a=commitdiff;h=5fa6aa9

The following commit has been merged in the master branch:
commit 5fa6aa95fe69a650bb8f6215f856d382d588d634
Author: Andreas Huggel <ahuggel at gmx.net>
Date:   Fri Apr 2 01:44:34 2004 +0000

    Minor change
---
 src/actions.cpp | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/actions.cpp b/src/actions.cpp
index d84d9c3..90422e0 100644
--- a/src/actions.cpp
+++ b/src/actions.cpp
@@ -20,13 +20,13 @@
  */
 /*
   File:      actions.cpp
-  Version:   $Name:  $ $Revision: 1.11 $
+  Version:   $Name:  $ $Revision: 1.12 $
   Author(s): Andreas Huggel (ahu) <ahuggel at gmx.net>
   History:   08-Dec-03, ahu: created
  */
 // *****************************************************************************
 #include "rcsid.hpp"
-EXIV2_RCSID("@(#) $Name:  $ $Revision: 1.11 $ $RCSfile: actions.cpp,v $")
+EXIV2_RCSID("@(#) $Name:  $ $Revision: 1.12 $ $RCSfile: actions.cpp,v $")
 
 // *****************************************************************************
 // included header files
@@ -218,14 +218,14 @@ namespace Action {
             }
         }
 
-        // Exposure program from ExposureProgram or Canon Makernote
-        rc = printTag(exifData, "Image.CaptureConditions.ExposureProgram", "Exposure");
+        // Exposure mode from ExposureProgram or Canon Makernote
+        rc = printTag(exifData, "Image.CaptureConditions.ExposureProgram", "Exposure mode");
         if (rc == 0) {
             md = exifData.findKey("Makernote.Canon.CameraSettings1");
             if (md != exifData.end() && md->count() >= 20) {
                 long prg = md->toLong(20);
                 std::cout << std::setw(align_) << std::setfill(' ') << std::left
-                          << "Exposure" << ": ";
+                          << "Exposure mode" << ": ";
                 Exif::CanonMakerNote::print0x0001_20(std::cout, prg);
                 std::cout << "
";
             }

-- 
exiv2 packaging



More information about the pkg-kde-commits mailing list